%define anolis_release 2

# Scan ext file systems directly to increase the performace of a quota
# initialization and check
%bcond_without quota_enables_extdirect
# Use netlink to monitor quota usage and warn interactive users
%bcond_without quota_enables_netlink
# Enable getting quotas remotely over network
%bcond_without quota_enables_rpc
# Allow setting quota remotely over network
%bcond_without quota_enables_rpcsetquota
# Disable TCP Wrappers guard in the RPC quota daemon
%bcond_with quota_enables_tcpwrappers

Name:       quota
Epoch:      1
Version:    4.09
Release:    %{anolis_release}%{?dist}
Summary:    System administration tools for monitoring users disk usage

License:    GPLv2 and GPLv2+
URL:        http://sourceforge.net/projects/linuxquota/
Source0:    http://downloads.sourceforge.net/linuxquota/%{name}-%{version}.tar.gz
Source1:    quota_nld.service
Source2:    quota_nld.sysconfig
Source3:    rpc-rquotad.service
Source4:    rpc-rquotad.sysconfig

BuildRequires:  autoconf automake bash coreutils gcc make
BuildRequires:  pkgconfig(ext2fs) pkgconfig(ldap) gettext-devel

%if %{with quota_enables_extdirect}
BuildRequires:  pkgconfig(com_err) pkgconfig(ext2fs)
%endif
%if %{with quota_enables_netlink}
BuildRequires:  pkgconfig(dbus-1) systemd-rpm-macros
BuildRequires:  pkgconfig(libnl-3.0) >= 3.1 pkgconfig(libnl-genl-3.0)
%endif
%if %{with quota_enables_rpc}
BuildRequires:  rpcgen pkgconfig(libtirpc) systemd-rpm-macros
%if %{with quota_enables_tcpwrappers}
BuildRequires:  tcp_wrappers-devel
%endif
%endif

Requires:       quota-nls = %{EVR}
Conflicts:      kernel < 2.4

%description
The quota subsystem allows a system administrator to set soft and hard
limits on used space and the number of inodes used for users and
groups. The kernel must be compiled with disk quota support enabled.

%if %{with quota_enables_rpc}
%package devel
Summary:    Development files for quota RPC
License:    GPLv2
Requires:   pkgconfig(libtirpc)

%description devel
This package contains development header files for implementing disk quotas
on remote machines.
%endif

%if %{with quota_enables_netlink}
%package nld
Summary:    quota_nld daemon
License:    GPLv2 and GPLv2+
Requires:   quota-nls = %{EVR}
Requires:   systemd

%description nld
quota_nld is a daemon that listens on netlink socket and processes received quota warnings. 
It forwards warning messages to both the system’s DBUS (so that the desktop manager can 
display a dialog) and the last-accessed terminal of the user to whom each warning is directed
%endif

%if %{with quota_enables_rpc}
%package rpc
Summary:    RPC quota daemon
License:    LGPLv2+ and GPLv2 and GPLv2+
Requires:   quota-nls = %{EVR}
Requires:   rpcbind systemd
%if %{with quota_enables_tcpwrappers}
Requires:   tcp_wrappers
%endif
Conflicts:  quota < 1:4.02-3

%description rpc
The RPC daemon allows to query and set disk quotas over network. If you run
the daemon on NFS server, you could use quota tools to manage the quotas from
NFS client.
%endif

%package warnquota
Summary:    Send e-mail to users over quota
License:    GPLv2 and GPLv2+
Requires:   quota-nls = %{EVR}

%description warnquota
Utility that checks disk quota for each local file system and mails a warning
message to those users who have reached their soft limit.  It is typically run
via cron(8).

%package nls
Summary:    Gettext catalogs for disk quota tools
License:    LGPLv2+ and GPLv2 and GPLv2+
BuildArch:  noarch

%description nls
This packages is disk quota tools messages translated into different natural languages.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1
# Regenerate build scripts
autoreconf -f -i

%build
%global _hardened_build 1
%configure \
    --enable-bsd-behaviour \
%if %{with quota_enables_extdirect}
    --enable-ext2direct=yes \
%else
    --enable-ext2direct=no \
%endif
    --enable-ldapmail=yes \
%if %{with quota_enables_tcpwrappers}
    --enable-libwrap=yes \
%else
    --disable-libwrap \
%endif
%if %{with quota_enables_netlink}
    --enable-netlink=yes \
%else
    --disable-netlink \
%endif
    --enable-nls \
    --with-pid-dir=/run \
    --disable-rpath \
%if %{with quota_enables_rpc}
    --enable-rpc=yes \
%else
    --disable-rpc \
%endif
%if %{with quota_enables_rpcsetquota}
    --enable-rpcsetquota=yes \
%else
    --disable-rpcsetquota \
%endif
    --disable-silent-rules \
    --disable-xfs-roothack
%{make_build}


%install
%{make_install}
rm -rf %{buildroot}%{_docdir}/%{name}

%if %{with quota_enables_netlink}
install -p -m644 -D %{SOURCE1} %{buildroot}%{_unitdir}/quota_nld.service
install -p -m644 -D %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/quota_nld
%endif
%if %{with quota_enables_rpc}
install -p -m644 -D %{SOURCE3} %{buildroot}%{_unitdir}/rpc-rquotad.service
install -p -m644 -D %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/rpc-rquotad
%endif

%find_lang %{name}

%generate_compatibility_deps

%check
make check

%if %{with quota_enables_netlink}
%post nld
%systemd_post quota_nld.service

%preun nld
%systemd_preun quota_nld.service

%postun nld
%systemd_postun_with_restart quota_nld.service
%endif

%if %{with quota_enables_rpc}
%post rpc
%systemd_post rpc-rquotad.service

%preun rpc
%systemd_preun rpc-rquotad.service

%postun rpc
%systemd_postun_with_restart rpc-rquotad.service
%endif

%files
%{_bindir}/*
%{_sbindir}/*
%dir %{abidir}
%{abidir}/*-option.list
%exclude %{_sbindir}/quota_nld
%if %{with quota_enables_rpc}
%exclude %{_sbindir}/rpc.rquotad
%endif
%exclude %{_sbindir}/warnquota
%{_mandir}/man1/*
%{_mandir}/man8/*
%exclude %{_mandir}/man8/quota_nld.8*
%if %{with quota_enables_rpc}
%exclude %{_mandir}/man8/rpc.rquotad.8*
%endif
%exclude %{_mandir}/man8/warnquota.8*

%if %{with quota_enables_rpc}
%files devel
%license COPYING
%dir %{_includedir}/rpcsvc
%{_includedir}/rpcsvc/*
%{_mandir}/man3/*
%endif


%if %{with quota_enables_netlink}
%files nld
%config(noreplace) %{_sysconfdir}/sysconfig/quota_nld
%{_unitdir}/quota_nld.service
%{_sbindir}/quota_nld
%{_mandir}/man8/quota_nld.8*
%endif

%if %{with quota_enables_rpc}
%files rpc
%config(noreplace) %{_sysconfdir}/sysconfig/rpc-rquotad
%{_unitdir}/rpc-rquotad.service
%{_sbindir}/rpc.rquotad
%{_mandir}/man8/rpc.rquotad.8*
%endif

%files warnquota
%config(noreplace) %{_sysconfdir}/quotagrpadmins
%config(noreplace) %{_sysconfdir}/quotatab
%config(noreplace) %{_sysconfdir}/warnquota.conf
%{_sbindir}/warnquota
%{_mandir}/man5/*
%{_mandir}/man8/warnquota.8*

%files nls -f %{name}.lang
%license COPYING

%files doc
%doc doc/* ldap-scripts
%doc Changelog README.ldap-support README.mailserver

%changelog
* Thu Apr 13 2023 yuanhui <yuanhui@linux.alibaba.com> - 4.09-2
- Optimize the spec file

* Wed Mar 01 2023 Ziyang Zhang <ZiyangZhang@linux.alibaba.com> - 4.09-1
- Update to 4.09

* Thu Oct 13 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.06-2
- optimise spec file

* Fri Mar 11 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 4.06-1
- Init from upstream version 4.06
